<?php
/**
 * Plugin Name: WP-Twitter Retweet Button
 * Plugin URI: http://blog.ppfeufer.de/wordpress-plugin-wp-twitter-button/
 * Description: This plugin will install the official Twitter Button provided by Twitter to your Wordpress-Blog.
 * Version: 1.5.2
 * Author: H.-Peter Pfeufer
 * Author URI: http://ppfeufer.de
 */

/**
 * Changelog:
 * 		= 1.5.2 =
 * 		Replaced deprecates function for language support with new one
 *
 * 		= 1.5.1 =
 * 		Updated french trabslation (by Frank from http://www.frankoli.de/blog/)
 *
 * 		= 1.5.0 =
 * 		Added Support for #Hashtags
 *
 * 		= 1.4.0 =
 * 		Option to display in archive-view added (Note: not all themes support this option)
 * 		Option to display in category-view added (Note: not all themes support this option)
 * 		Fixed the code for displaying in RSS
 * 		Modified german translation
 * 		Updated screenshot :-)
 *
 * 		= 1.3.1 =
 * 		Renamed menu WP-Twitter to Twitterbutton to avoid any confusion with the WP to Twitter Plugin
 * 		Added translation in dashboardmenu (Twitterbutton -> Settings)
 *
 *		= 1.3.0 =
 *		Added german translation
 *		Added french translation (by Frank from http://www.frankoli.de/blog/)
 *
 *		= 1.2.1 =
 *		Fixed a little typo in the rss-settings
 *		Added options for position in rss
 *
 *		= 1.2.0 =
 *		Buttonlanguage added
 *		Option to display button on frontpage added
 *		Option to display button on rss-feed added
 *		Option for own tweetext added
 *
 *		= 1.1.1 =
 *		Codecorrection
 *
 *		= 1.1.0 =
 *		Added Support for all the three buttons provided by Twitter. Selectable in Settings.
 *
 *		= 1.0.0 =
 *		Initial Release
 */

/**
 * Button Menü zum Dashboard hinzufügen
 */
function wp_twitter_options() {
	add_menu_page('Twitterbutton', 'Twitterbutton', 8, basename(__FILE__), 'wp_twitter_options_page');
	add_submenu_page(basename(__FILE__), __('Settings'), __('Settings'), 8, basename(__FILE__), 'wp_twitter_options_page');
}

/**
 * Buttons generieren
 */
function wp_twitter_generate_button() {
	$url = get_permalink();
	$tweettext = wp_twitter_get_tweettext();

	return '<div class="wp_twitter_button" style="' . get_option('wp_twitter_style') . '">
				<a href="http://twitter.com/share?counturl=' . urlencode($url) . '" class="twitter-share-button" data-url="' . $url . '" data-count="' . get_option('wp_twitter_version') . '" data-via="' . get_option('wp_twitter_source') . '" data-lang="' . get_option('wp_twitter_language') . '" ' . $tweettext . '>Tweet</a>
				<script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>
			</div>';
}

function wp_twitter_generate_static_button() {
	if(get_post_status($post->ID) == 'publish') {
		$url = get_permalink();
		$tweettext = wp_twitter_get_tweettext();

		return '<div class="wp_twitter_button" style="' . get_option('wp_twitter_style') . '">
					<a href="http://twitter.com/share?counturl=' . urlencode($url) . '" class="twitter-share-button" data-url="' . $url . '" data-count="' . get_option('wp_twitter_version') . '" data-via="' . get_option('wp_twitter_source') . '" data-lang="' . get_option('wp_twitter_language') . '" ' . $tweettext . '>Tweet</a>
					<script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>
				</div>';
	} else {
		return;
	}
}

/**
 * Eigenen Tweettext einbinden
 */
function wp_twitter_get_tweettext() {
	$tweettext = '';
	if (get_option('wp_twitter_tweettext') == 'own') {
		$tweettext = 'data-text="' . get_option('wp_twitter_tweettext_owntext') . wp_twitter_get_hashtags() . '"';
	} else {
		/**
		 * Abfragen wo der Button eigebunden ist.
		 *
		 * $tweettext anpassen wenn:
		 * 		is_home()		=> Startseite
		 * 		is_archive()	=> Archivansicht
		 * 		is_category()	=> Kategorieansicht
		 * 		is_feed()		=> RSS-Feed
		 */
		if ((get_option('wp_twitter_display_front') == '1' && is_home()) || (get_option('wp_twitter_display_archive') == '1' && is_archive()) || (get_option('wp_twitter_display_category') == '1' && is_category()) || (get_option('wp_twitter_display_feed') == '1' && is_feed())) {
			$tweettext = 'data-text="' . the_title('', '', false) . ' | ' . get_bloginfo('name') . wp_twitter_get_hashtags() . '"';
		} else {
			return;
		}
	}

	return $tweettext;
}

/**
 * Tags des Artikels in #Hashtags umwandeln
 */
function wp_twitter_get_hashtags() {
	/**
	 * Sollen #Hashtags angezeigt werden?
	 */
	if (get_option('wp_twitter_hashtags') == '1') {
		$hashtags = strip_tags(get_the_tag_list(' #', ' #', ''));
	} else {
		$hashtags = '';
	}

	return $hashtags;
}

/**
 * The Loop
 */
function wp_twitter_update($content) {
	global $post;

	/**
	 * Manual Option
	 */
	if(get_option('wp_twitter_where') == 'manual') {
		return $content;
	}

	/**
	 * Sind wir auf einer CMS-Seite?
	 */
	if(get_option('wp_twitter_display_page') == null && is_page()) {
		return $content;
	}

	/**
	 * Sind wir auf der Startseite?
	 */
	if(get_option('wp_twitter_display_front') == null && is_home()) {
		return $content;
	}

	/**
	 * Sind wir in der Achiveanzeige?
	 */
	if(get_option('wp_twitter_display_archive') == null && is_archive()) {
		return $content;
	}

	/**
	 * Sind wir in der Kategorieanzeige?
	 */
	if(get_option('wp_twitter_display_category') == null && is_category()) {
		return $content;
	}

	/**
	 * Ist es ein Feed
	 */
	if (is_feed()) {
		$button = wp_twitter_generate_static_button();
		$where = 'wp_twitter_rss_where';
	} else {
		$button = wp_twitter_generate_button();
		$where = 'wp_twitter_where';
	}

	/**
	 * Soll der Button im Feed ausgeblendet werden?
	 */
	if (is_feed() && get_option('wp_twitter_display_feed') == null) {
		return $content;
	}

	/**
	 * Wurde der Shortcode genutzt
	 */
	if(get_option($where) == 'shortcode') {
		return str_replace('[wp_twitter]', $button, $content);
	} else {
		/**
		 * Wenn wir den Button abgeschalten haben
		 */
		if(get_post_meta($post->ID, 'wp_twitter') == null) {
			if(get_option($where) == 'beforeandafter') {
				/**
				 * Vor und nach dem Beitrag einfügen
				 */
				return $button . $content . $button;
			} else if(get_option($where) == 'before') {
				/**
				 * Vor dem Beitrag einfügen
				 */
				return $button . $content;
			} else {
				/**
				 * Nach dem Beitrag einfügen
				 */
				return $content . $button;
			}
		} else {
			/**
			 * Keinen Button einfügen
			 */
			return $content;
		}
	}
}

/**
 * Manuelle Ausgabe
 */
function wp_twitterbutton() {
	if(get_option('wp_twitter_where') == 'manual') {
		return wp_twitter_generate_button();
	} else {
		return false;
	}
}

/**
 * Filter durch Vorschau entfernen
 * @param string $content
 */
function wp_twitter_remove_filter($content) {
	if(!is_feed()) {
		remove_action('the_content', 'wp_twitter_update');
	}
	return $content;
}

/**
 * Meta-Tag 'wp_twitter-title' setzen.
 */
function wp_twitter_head() {
	/**
	 * Sind wir in einem Artikel?
	 */
	if(is_single()) {
		global $post;
		$title = get_the_title($post->ID);
		echo '<meta name="wp_twitter-title" content="' . strip_tags($title) . '" />';
	}
}

/**
 * Optionsseite generieren
 */
function wp_twitter_options_page() {
	?>
	<div class="wrap">
		<div class="icon32" id="icon-options-general"><br /></div>
		<h2><?php _e('Settings for WP Twitter Button', 'wp-twitter-button'); ?></h2>
		<p><?php _e('This plugin will install the WP Twitter Button widget for each of your blog posts.', 'wp-twitter-button'); ?></p>
		<form method="post" action="options.php">
			<?php
			// New way of setting the fields, for WP 2.7 and newer
			if(function_exists('settings_fields')) {
				settings_fields('wp_twitter-options');
			}
			?>
			<table class="form-table">
				<tr>
					<th scope="row" valign="top"><?php _e('Display', 'wp-twitter-button'); ?></th>
					<td>
						<div>
							<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_page') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_page" id="wp_twitter_display_page" group="wp_twitter_display" />
							<label for="wp_twitter_display_page"><?php _e('Display the button on pages', 'wp-twitter-button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_front') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_front" id="wp_twitter_display_front" group="wp_twitter_display" />
							<label for="wp_twitter_display_front"><?php _e('Display the button on front page (home)', 'wp-twitter-button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_archive') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_archive" id="wp_twitter_display_archive" group="wp_twitter_display" />
							<label for="wp_twitter_display_archive"><?php _e('Display the button on archive-view <em>(<strong>Note</strong>: not all themes support this option)</em>', 'wp-twitter-button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_category') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_category" id="wp_twitter_display_category" group="wp_twitter_display" />
							<label for="wp_twitter_display_category"><?php _e('Display the button on category-view <em>(<strong>Note</strong>: not all themes support this option)</em>', 'wp-twitter-button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_feed') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_feed" id="wp_twitter_display_feed" group="wp_twitter_display" />
							<label for="wp_twitter_display_feed"><?php _e('Display the button on rss-feed', 'wp-twitter-button'); ?></label>
						</div>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e('Position', 'wp-twitter-button'); ?></th>
					<td>
						<select name="wp_twitter_where">
							<option <?php if(get_option('wp_twitter_where') == 'before') echo 'selected="selected"'; ?> value="before"><?php _e('Before', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_where') == 'after') echo 'selected="selected"'; ?> value="after"><?php _e('After', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_where') == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter"><?php _e('Before and After', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_where') == 'shortcode') echo 'selected="selected"'; ?> value="shortcode"><?php _e('Shortcode [wp_twitter]', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_where') == 'manual') echo 'selected="selected"'; ?> value="manual"><?php _e('Manual', 'wp-twitter-button'); ?></option>
						</select>
						<?php if(get_option('wp_twitter_where') == 'manual') : ?>
							<p><?php _e('Add the following code to your template', 'wp-twitter-button'); ?></p>
							<p>
								<code>
									&lt;?php if(function_exists('wp_twitterbutton')) { wp_twitterbutton(); } ?&gt;
								</code>
							</p>
						<?php endif; ?>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e('RSS Position', 'wp-twitter-button'); ?></th>
					<td>
						<select name="wp_twitter_rss_where">
							<option <?php if (get_option('wp_twitter_rss_where') == 'before') echo 'selected="selected"'; ?> value="before"><?php _e('Before', 'wp-twitter-button'); ?></option>
							<option <?php if (get_option('wp_twitter_rss_where') == 'after') echo 'selected="selected"'; ?> value="after"><?php _e('After', 'wp-twitter-button'); ?></option>
							<option <?php if (get_option('wp_twitter_rss_where') == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter"><?php _e('Before and After', 'wp-twitter-button'); ?></option>
							<option <?php if (get_option('wp_twitter_where') == 'shortcode') echo 'selected="selected"'; ?> value="shortcode"><?php _e('Shortcode [wp_twitter]', 'wp-twitter-button'); ?></option>
						</select>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e('Type', 'wp-twitter-button'); ?></th>
					<td>
						<div style="float:left; width:32%;">
							<p>
								<input type="radio" value="vertical" <?php if (get_option('wp_twitter_version') == 'vertical') echo 'checked="checked"'; ?> name="wp_twitter_version" id="wp_twitter_version_vertical" group="wp_twitter_version"/>
								<label for="wp_twitter_version_large"><?php _e('Vertical count', 'wp-twitter-button'); ?></label>
							</p>
							<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/tweetv.png" /></p>
						</div>
						<div style="float:left; width:32%;">
							<p>
								<input type="radio" value="horizontal" <?php if (get_option('wp_twitter_version') == 'horizontal') echo 'checked="checked"'; ?> name="wp_twitter_version" id="wp_twitter_version_horizontal" group="wp_twitter_version" />
								<label for="wp_twitter_version_compact"><?php _e('Horizontal count', 'wp-twitter-button'); ?></label>
							</p>
							<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/tweeth.png" /></p>
						</div>
						<div style="float:left; width:32%;">
							<p>
								<input type="radio" value="none" <?php if (get_option('wp_twitter_version') == 'none') echo 'checked="checked"'; ?> name="wp_twitter_version" id="wp_twitter_version_none" group="wp_twitter_version" />
								<label for="wp_twitter_version_compact"><?php _e('No count', 'wp-twitter-button'); ?></label>
							</p>
							<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/tweetn.png" /></p>
						</div>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><label for="wp_twitter_style"><?php _e('Styling', 'wp-twitter-button'); ?></label></th>
					<td>
						<input type="text" value="<?php echo htmlspecialchars(get_option('wp_twitter_style')); ?>" name="wp_twitter_style" id="wp_twitter_style" />
						<span class="description"><?php _e('Add style to the div that surrounds the button E.g. <code>float: left; margin-right: 10px;</code>', 'wp-twitter-button'); ?></span>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><label for="wp_twitter_source"><?php _e('Source', 'wp-twitter-button'); ?></label></th>
					<td>
						RT @<input type="text" value="<?php echo get_option('wp_twitter_source'); ?>" name="wp_twitter_source" id="wp_twitter_source" />
						<span class="description"><?php _e('Please use the format of \'yourname\', not \'RT @yourname\'.', 'wp-twitter-button'); ?></span>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><label for="wp_twitter_source"><?php _e('Language', 'wp-twitter-button'); ?></label></th>
					<td>
						<select name="wp_twitter_language">
							<option <?php if(get_option('wp_twitter_language') == '') echo 'selected="selected"'; ?> value=""><?php _e('English', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_language') == 'fr') echo 'selected="selected"'; ?> value="fr"><?php _e('French', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_language') == 'de') echo 'selected="selected"'; ?> value="de"><?php _e('German', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_language') == 'es') echo 'selected="selected"'; ?> value="es"><?php _e('Spanish', 'wp-twitter-button'); ?></option>
							<option <?php if(get_option('wp_twitter_language') == 'ja') echo 'selected="selected"'; ?> value="ja"><?php _e('Japanese', 'wp-twitter-button'); ?></option>
						</select>
						<span class="description"><?php _e('The language of the button.', 'wp-twitter-button'); ?></span>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><label for="wp_twitter_source"><?php _e('Tweet-Text', 'wp-twitter-button'); ?></label></th>
					<td>
						<div>
							<input type="radio" value="default" <?php if (get_option('wp_twitter_tweettext') == 'default') echo 'checked="checked"'; ?> name="wp_twitter_tweettext" id="wp_twitter_tweettext_default" group="wp_twitter_tweettext" />
							<label for="wp_twitter_tweettext_default"><?php _e('The title of the page the button is on.', 'wp-twitter-button'); ?></label>
						</div>
						<div>
							<input type="radio" value="own" <?php if (get_option('wp_twitter_tweettext') == 'own') echo 'checked="checked"'; ?> name="wp_twitter_tweettext" id="wp_twitter_tweettext_own" group="wp_twitter_tweettext" />
							<input type="text" value="<?php echo get_option('wp_twitter_tweettext_owntext'); ?>" name="wp_twitter_tweettext_owntext" id="wp_twitter_tweettext_owntext" />
							<span class="description"><?php _e('This is the text that people will include in their Tweet when they share from your website.', 'wp-twitter-button'); ?></span>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(get_option('wp_twitter_hashtags') == '1') echo 'checked="checked"'; ?> name="wp_twitter_hashtags" id="wp_twitter_hashtags" group="wp_twitter_tweettext" />
							<label for="wp_twitter_hashtags"><?php _e('Use tags as #hashtags', 'wp-twitter-button'); ?></label>
						</div>
					</td>
				</tr>
			</table>
			<p class="submit"><input type="submit" name="Submit" value="<?php _e('Save Changes', 'wp-twitter-button'); ?>" /></p>
		</form>
	</div>
<?php
}

function wp_twitter_settings_link( $links, $file ) {
 	if( $file == 'wp-twitter-retweet-button/wp-twitter-button.php' && function_exists( "admin_url" ) ) {
		$settings_link = '<a href="' . admin_url( 'admin.php?page=wp-twitter-button.php' ) . '">' . __('Settings') . '</a>';
		array_unshift( $links, $settings_link ); // before the other links
	}
	return $links;
}

/**
 * Variablen registrieren
 */
function wp_twitter_init() {
	if(function_exists('register_setting')) {
		register_setting('wp_twitter-options', 'wp_twitter_display_page');
		register_setting('wp_twitter-options', 'wp_twitter_display_front');
		register_setting('wp_twitter-options', 'wp_twitter_display_feed');
		register_setting('wp_twitter-options', 'wp_twitter_display_archive');
		register_setting('wp_twitter-options', 'wp_twitter_display_category');
		register_setting('wp_twitter-options', 'wp_twitter_source', 'wp_twitter_sanitize_username');
		register_setting('wp_twitter-options', 'wp_twitter_style');
		register_setting('wp_twitter-options', 'wp_twitter_rss_where');
		register_setting('wp_twitter-options', 'wp_twitter_where');
		register_setting('wp_twitter-options', 'wp_twitter_language');
		register_setting('wp_twitter-options', 'wp_twitter_version');
		register_setting('wp_twitter-options', 'wp_twitter_tweettext');
		register_setting('wp_twitter-options', 'wp_twitter_tweettext_owntext');
		register_setting('wp_twitter-options', 'wp_twitter_hashtags');
	}

	/**
	 * Sprachdatei wählen
	 */
	if(function_exists('load_plugin_textdomain')) {
		load_plugin_textdomain('wp-twitter-button', false, dirname(plugin_basename( __FILE__ )) . '/languages/');
		/**
		 * This is deprecated
		 */
//		$strLocale = get_locale();
//		if ( !empty( $strLocale ) ) {
//			$strMOfile = ABSPATH . 'wp-content/plugins/' . basename(dirname(__FILE__)) . '/languages/wp-twitter-button-' . $strLocale . '.mo';
//			load_textdomain('wp_twitter', $strMOfile);
//		}
	}
}

/**
 * Twittername angleichen
 * 		Nicht erwünschte Zeichen entfernen
 *
 * @param string $username
 */
function wp_twitter_sanitize_username($username) {
	return preg_replace('/[^A-Za-z0-9_]/', '', $username);
}

/**
 * Nur wenn User auch der Admin ist, sind die Adminotionen zu sehen
 */
if(is_admin()) {
	add_action('admin_menu', 'wp_twitter_options');
	add_action('admin_init', 'wp_twitter_init');
}

/**
 * Standardwerte setzen
 */
function wp_twitter_activate() {
	add_option('wp_twitter_where', 'before');
	add_option('wp_twitter_rss_where', 'before');
	add_option('wp_twitter_language', 'de');
	add_option('wp_twitter_source');
	add_option('wp_twitter_style', 'float: right; margin-left: 10px;');
	add_option('wp_twitter_display_page', '1');
	add_option('wp_twitter_display_front', '0');
	add_option('wp_twitter_display_archive', '0');
	add_option('wp_twitter_display_category', '0');
	add_option('wp_twitter_display_feed', '0');
	add_option('wp_twitter_version', 'vertical');
	add_option('wp_twitter_tweettext', 'default');
	add_option('wp_twitter_tweettext_owntext', '');
	add_option('wp_twitter_hashtags', '1');
}

/**
 * Filter zum Blog hinzufügen
 */
add_filter('the_content', 'wp_twitter_update', 8);
add_filter('get_the_excerpt', 'wp_twitter_remove_filter', 9);
add_filter('plugin_action_links', 'wp_twitter_settings_link', 9, 2 );

/**
 * Header erweitern
 */
add_action('wp_head', 'wp_twitter_head');

/**
 * Button aktivieren
 */
register_activation_hook(__FILE__, 'wp_twitter_activate');
?>